@@ -47,10 +47,7 @@ clearlooks_get_parent_bg (const GtkWidget *widget, CairoColor *color)
 	GdkColor *gcolor;
 	
 	if (widget == NULL)
-	{
-		color->r = color->g = color->b = 255;
 		return;
-	}
 	
 	parent = widget->parent;
 	
@@ -58,7 +55,7 @@ clearlooks_get_parent_bg (const GtkWidget *widget, CairoColor *color)
 		parent = parent->parent;
 
 	if (parent == NULL)
-		parent = widget;
+		return;
 	
 	state_type = GTK_WIDGET_STATE (parent);
 	
@@ -76,7 +73,8 @@ clearlooks_scrollbar_get_stepper (GtkWidget    *widget,
 	GdkRectangle check_rectangle;
 	GtkOrientation orientation;
 
-	g_return_val_if_fail (IS_RANGE (widget), CL_STEPPER_UNKNOWN);
+	if (!GE_IS_RANGE (widget))
+		return CL_STEPPER_UNKNOWN;
 
 	check_rectangle.x      = widget->allocation.x;
 	check_rectangle.y      = widget->allocation.y;
@@ -132,7 +130,7 @@ clearlooks_scrollbar_visible_steppers (GtkWidget *widget)
 {
 	ClearlooksStepper steppers = 0;
 	
-	if (!IS_RANGE (widget))
+	if (!GE_IS_RANGE (widget))
 		return 0;
 	
 	if (GTK_RANGE (widget)->has_stepper_a)
@@ -156,7 +154,7 @@ clearlooks_scrollbar_get_junction (GtkWidget    *widget)
 	GtkAdjustment *adj;
 	ClearlooksJunction junction = CL_JUNCTION_NONE;
 	
-	if (!IS_RANGE (widget))
+	if (!GE_IS_RANGE (widget))
 		return CL_JUNCTION_NONE;
 
 	adj = GTK_RANGE (widget)->adjustment;
